@@ -1,23 +1,17 @@
-require 5.008_000;
-use utf8;
-
 package Text::MultiMarkdown;
+require 5.008_000;
 use strict;
 use warnings;
 use re 'eval';
 
-use Digest::MD5    qw(md5_hex);
-use Encode         qw();
-use Carp           qw(carp croak);
-use base           qw(Text::Markdown);
-use HTML::Entities qw(encode_entities);
-use Scalar::Util   qw(blessed);
-use Unicode::Normalize ();
+use Digest::MD5 qw(md5_hex);
+use Encode      qw();
+use Carp        qw(croak);
+use base        qw(Text::Markdown);
 
-our $VERSION   = '1.002_04';
-our @EXPORT_OK = qw(markdown multimarkdown_to_html);
-
-=encoding utf8
+our $VERSION   = '1.000031'; # 1.0.31
+$VERSION = eval $VERSION;
+our @EXPORT_OK = qw(markdown);
 
 =head1 NAME
 
@@ -25,25 +19,21 @@ Text::MultiMarkdown - Convert MultiMarkdown syntax to (X)HTML
 
 =head1 SYNOPSIS
 
-Use it as a function, with or without optional arguments:
-
     use Text::MultiMarkdown 'markdown';
-
     my $html = markdown($text);
 
+    use Text::MultiMarkdown 'markdown';
     my $html = markdown( $text, {
         empty_element_suffix => '>',
         tab_width => 2,
         use_wikilinks => 1,
     } );
 
-Or in the object-oriented interface:
-
     use Text::MultiMarkdown;
-
     my $m = Text::MultiMarkdown->new;
     my $html = $m->markdown($text);
 
+    use Text::MultiMarkdown;
     my $m = Text::MultiMarkdown->new(
         empty_element_suffix => '>',
         tab_width => 2,
@@ -63,7 +53,7 @@ specifically to serve as a front-end to (X)HTML. You can use span-level
 HTML tags anywhere in a Markdown document, and you can use block level
 HTML tags (C<< <div> >>, C<< <table> >> etc.). Note that by default
 Markdown isn't interpreted in HTML block-level elements, unless you add
-a C<markdown="1"> attribute to the element. See L<Text::Markdown> for
+a C<markdown=1"> attribute to the element. See L<Text::Markdown> for 
 details.
 
 This module implements the MultiMarkdown markdown syntax extensions from:
@@ -86,121 +76,98 @@ and borrows from php-markdown, which lives at:
 
     http://michelf.com/projects/php-markdown/extra/
 
-This documentation is going to be moved/copied into this module for
-clearer reading in a future release..
+This documentation is going to be moved/copied into this module for clearer reading in a future release..
 
-=head2 Options
+=head1 OPTIONS
 
-MultiMarkdown supports a number of options to its processor which
-control the behaviour of the output document.
+MultiMarkdown supports a number of options to it's processor which control the behaviour of the output document.
 
-These options can be supplied to the constructor, on in a hash with
-the individual calls to the markdown method. See the synopsis for
-examples of both of the above styles.
+These options can be supplied to the constructor, on in a hash with the individual calls to the markdown method.
+See the synopsis for examples of both of the above styles.
 
 The options for the processor are:
 
-=over 4
-
-=item bibliography_title
-
-The title of the generated bibliography, defaults to 'Bibliography'.
-
-=item disable_bibliography
-
-If true, this disables the MultiMarkdown bibliography/citation handling.
-
-=item disable_definition_lists
-
-If true, this disables the MultiMarkdown definition list handling.
-
-=item disable_footnotes
-
-If true, this disables the MultiMarkdown footnotes handling.
-
-=item disable_tables
-
-If true, this disables the MultiMarkdown table handling.
-
-=item empty_element_suffix
-
-This option can be used to generate normal HTML output. By default, it
-is C<< /> >>, which is xHTML, change to C<< > >> for normal HTML.
-
-=item heading_ids
-
-Controls if C<hX> tags generated have an id attribute. Defaults to true.
-Turn off for compatibility with the original markdown.
-
-=item heading_ids_spaces_to_dash
-
-Controls whether spaces in headings should be rendered as "-" characters
-in the heading ids (for compatibility with GitHub markdown, and others)
-
-=item img_ids
-
-Controls if C<img> tags generated have an id attribute. Defaults to true.
-Turn off for compatibility with the original markdown.
-
-=item strip_metadata
-
-If true, any metadata in the input document is removed from the output
-document (note - does not take effect in complete document format).
-
-=item tab_width
-
-Controls indent width in the generated markup, defaults to 4
-
-=item transliterated_ids
-
-In markdown label values, change accented and other non-ASCII letter
-characters with L<Text::Unidecode>. If that module is not available,
-this issues a warning and does nothing. When C<unicode_ids> is true,
-this is ignored. The default is false.
-
-=item unicode_ids
-
-In markdown label values, allow any Unicode letter character along
-with the allowed ASCII symbol characters. This overrules
-C<transliterated_ids> when true. The default is false.
+=over
 
 =item use_metadata
 
 Controls the metadata options below.
 
+=item strip_metadata
+
+If true, any metadata in the input document is removed from the output document (note - does not take effect in complete document format).
+
+=item empty element suffix
+
+This option can be used to generate normal HTML output. By default, it is ' />', which is xHTML, change to '>' for normal HTML.
+
+=item img_ids
+
+Controls if <img> tags generated have an id attribute. Defaults to true.
+Turn off for compatibility with the original markdown.
+
+=item heading_ids
+
+Controls if <hX> tags generated have an id attribute. Defaults to true.
+Turn off for compatibility with the original markdown.
+
+=item bibliography_title
+
+The title of the generated bibliography, defaults to 'Bibliography'.
+
+=item tab_width
+
+Controls indent width in the generated markup, defaults to 4
+
+=item disable_tables
+
+If true, this disables the MultiMarkdown table handling.
+
+=item disable_footnotes
+
+If true, this disables the MultiMarkdown footnotes handling.
+
+=item disable_bibliography
+
+If true, this disables the MultiMarkdown bibliography/citation handling.
+
 =back
 
-=head2 Metadata
+A number of possible items of metadata can also be supplied as options.
+Note that if the use_metadata is true then the metadata in the document will overwrite the settings on command line.
 
-MultiMarkdown supports the concept of 'metadata', which allows you to
-specify a number of formatting options within the document itself.
-Metadata should be placed in the top few lines of a file, on value per
-line as colon separated key/value pairs. The metadata should be
-separated from the document with a blank line.
+Metadata options supported are:
 
-Most metadata keys are also supported as options to the constructor,
-or options to the markdown method itself. (Note, as metadata, keys
-contain space, whereas options the keys are underscore separated.)
-
-You can attach arbitrary metadata to a document, which is output in
-HTML C<< <META> >> tags if unknown, see F<t/11-document_format.t> for
-an example.
-
-These are the known metadata keys:
-
-=over 4
+=over
 
 =item document_format
 
-If set to 'complete', MultiMarkdown will render an entire xHTML page,
-otherwise it will render a document fragment
+=item use_wikilinks
 
-=over 4
+=item base_url
 
-=item base url
+=back
 
-This is the base URL for referencing wiki pages. In this is not
-supplied, all wiki links are relative.
+=head1 METADATA
+
+MultiMarkdown supports the concept of 'metadata', which allows you to specify a number of formatting options
+within the document itself. Metadata should be placed in the top few lines of a file, on value per line as colon separated key/value pairs.
+The metadata should be separated from the document with a blank line.
+
+Most metadata keys are also supported as options to the constructor, or options
+to the markdown method itself. (Note, as metadata, keys contain space, whereas options the keys are underscore separated.)
+
+You can attach arbitrary metadata to a document, which is output in HTML <META> tags if unknown, see t/11document_format.t for more info.
+
+A list of 'known' metadata keys, and their effects are listed below:
+
+=over
+
+=item document format
+
+If set to 'complete', MultiMarkdown will render an entire xHTML page, otherwise it will render a document fragment
+
+=over
 
 =item css
 
@@ -214,302 +181,85 @@ Sets the page title, if in 'complete' document format.
 
 =item use wikilinks
 
-If set to '1' or 'on', causes links that are WikiWords to
-automatically be processed into links.
+If set to '1' or 'on', causes links that are WikiWords to automatically be processed into links.
+
+=item base url
+
+This is the base URL for referencing wiki pages. In this is not supplied, all wiki links are relative.
 
 =back
 
-=head2 Class methods
+=head1 METHODS
 
-=over 4
-
-=item new
+=head2 new
 
 A simple constructor, see the SYNTAX and OPTIONS sections for more information.
 
 =cut
 
-my %defaults;
-BEGIN {
-%defaults = (
-	use_metadata               => 1,
-	base_url                   => '',
-	tab_width                  => 4,
-	document_format            => '',
-	empty_element_suffix       => ' />',
-	use_wikilinks              => 0,
-	heading_ids                => 1,
-	img_ids                    => 1,
-	bibliography_title         => 'Bibliography',
-	self_url                   => '',
-	heading_ids_spaces_to_dash => '',
-	);
-
-}
-
 sub new {
-    my ($class, %args) = @_;
+    my ($class, %p) = @_;
 
-	my %p = ( %defaults, %args );
+    # Default metadata to 1
+    $p{use_metadata} = 1 unless exists $p{use_metadata};
+    # Squash value to [01]
+    $p{use_metadata} = $p{use_metadata} ? 1 : 0;
 
-	my @binary = qw(use_metadata use_wikilinks);
-	$p{$_} = $p{$_} ? 1 : 0 for @binary;
+    $p{base_url} ||= ''; # This is the base url to be used for WikiLinks
 
-	unless( $p{tab_width} =~ m/^[0-9]+$/ ) {
-		carp "tab_width did not look like a decimal number, so using the default 4";
-		$p{tab_width} = 4;
-	}
+    $p{tab_width} = 4 unless (defined $p{tab_width} and $p{tab_width} =~ m/^\d+$/);
 
-	_process_id_handler( \%args, \%p );
+    $p{document_format} ||= '';
+
+    $p{empty_element_suffix} ||= ' />'; # Change to ">" for HTML output
+
+    #$p{heading_ids} = defined $p{heading_ids} ? $p{heading_ids} : 1;
+
+    # For use with WikiWords and [[Wiki Links]]
+    # NOTE: You can use \WikiWord to prevent a WikiWord from being treated as a link
+    $p{use_wikilinks} = $p{use_wikilinks} ? 1 : 0;
+
+    $p{heading_ids} = defined $p{heading_ids} ? $p{heading_ids} : 1;
+    $p{img_ids}     = defined $p{img_ids}     ? $p{img_ids}     : 1;
+
+    $p{bibliography_title} ||= 'Bibliography'; # FIXME - Test and document, can also be in metadata!
 
     my $self = { params => \%p };
     bless $self, ref($class) || $class;
     return $self;
 }
 
-sub _id_handler {
-	defined $_[0]->{id_handler} ? $_[0]->{id_handler} : \&_default_id_handler
-}
+=head2 markdown
 
-sub _default_id_handler {
-	my ($label) = @_;
-
-	$label =~ s/[^A-Za-z0-9:_.-]//g;
-	$label =~ s/\A[^A-Za-z]+//g;
-	$label =~ s/-+/-/g;
-	$label =~ s/-+\z//g;
-
-	return $label;
-}
-
-BEGIN {
-my $has_unidecode = eval { require Text::Unidecode };
-
-sub _transliteration_id_handler {
-	my ($label) = @_;
-
-	unless ($has_unidecode ) {
-		carp "Need Text::Unidecode to for transliterated_ids, but could not load it. Falling back to default id handler";
-		return _default_id_handler($label);
-	}
-
-	$label = Text::Unidecode::unidecode($label);
-
-	$label =~ s/\s+//g;
-	$label =~ s/\A[^A-Za-z]+//g;
-	$label =~ s/-+/-/g;
-	$label =~ s/-+\z//g;
-
-	return $label;
-}
-
-{
-no warnings qw(redefine);
-*_transliteration_id_handler = \&_default_id_handler unless $has_unidecode;
-}
-
-sub _unicode_id_handler {
-	my ($label) = @_;
-
-	$label =~ s/\s+//g;
-	$label =~ s/\W+/-/g;
-	$label =~ s/\A\P{Letter}+//g;
-	$label =~ s/-+/-/g;
-	$label =~ s/-+\z//g;
-	return $label;
-}
-
-sub _process_id_handler {
-	my( $args, $p ) = @_;
-
-	$p->{id_handler} = \&_default_id_handler;
-
-	if ( exists $args->{unicode_ids} and $args->{unicode_ids} and exists $args->{transliterated_ids} ) {
-		warn "ignoring transliterated_ids because unicode_ids is true\n";
-		delete $args->{transliterated_ids};
-		}
-
-	if ( $args->{unicode_ids} ) {
-		$p->{id_handler} = \&_unicode_id_handler
-		}
-	elsif ( $args->{transliterated_ids} ) {
-		warn "Need Text::Unidecode to transliterate labels, but could not load it\n"
-			unless $has_unidecode;
-		$p->{id_handler} = \&_transliteration_id_handler;
-		}
-	}
-}
-
-=back
-
-=head2 Instance methods
-
-=over 4
-
-=item markdown( MARKDOWN_TEXT [, HASHREF] )
-
-This is the legacy interface to this module, but it does too much and
-is a poor name. For the function form, use C<multimarkdown_to_html>
-instead. At the moment that's just a wrapper for C<markdown> in the
-functional form. For the object-oriented forms, use C<to_html> instead.
-That's also just a wrapper for this, but will later change to enforce
-object-orientedness (i.e. exclude the functional form).
-
-And now the legacy stuff.
-
-This works as either a class method, instance method, or exportable
-function:
-
-	my $html = Text::MultiMarkdown->markdown( $text );
-
-	my $mm = Text::MultiMarkdown->new;
-	my $html = $mm->markdown($text);
-
-	use Text::MultiMarkdown qw(markdown);
-	my $html = markdown( $text );
-
-Any of these forms take an optional HASH_REF argument for options. These
-are the options for this module or the parent class L<Text::Markdown>:
-
-	my $html = Text::MultiMarkdown->markdown( $text, { ... } );
-
-	my $mm = Text::MultiMarkdown->new;
-	my $html = $mm->markdown($text, { ... });
-
-	use Text::MultiMarkdown qw(markdown);
-	my $html = markdown( $text, { ... } );
-
-To make this work in all these cases, since this was the legacy design,
-various unsavory things have to happen.
-
-When called as a class method, a new object is constructed. We guess
-that it's a class method by looking at the first argument and seeing
-that it looks like a Perl package name. In prior versions this was
-documented to not work, but there was also a TODO test for it to work.
-So, now it works. This might fail if the entire markdown text is exactly
-a valid Perl package name.
-
-If the first argument is a blessed reference, we guess that this is
-an instance method. With the optional HASH_REF argument this constructs
-a new argument with all of the settings of the original object and the
-stuff in HASH_REF. This might fail if you have some weird case where
-you call this as a function but pass as the TEXT argument an object that
-has overloaded stringification .
+The main function as far as the outside world is concerned. See the SYNOPSIS
+for details on use.
 
 =cut
 
-=begin comment
-
-=end comment
-
-There are these situations:
-
-	CLASS->markdown( TEXT );
-	CLASS->markdown( TEXT, HASHREF );
-
-	OBJ->markdown( TEXT );
-	OBJ->markdown( TEXT, HASHREF );
-
-	markdown( TEXT );
-	markdown( TEXT, HASHREF );
-
-These are really:
-
-	markdown( CLASS, TEXT )
-	markdown( CLASS, TEXT, HASHREF )
-
-	markdown( OBJ, TEXT )
-	markdown( OBJ, TEXT, HASHREF )
-
-	markdown( TEXT );
-	markdown( TEXT, HASHREF );
-
-Which breaks down to these groups:
-
-	1) markdown( TEXT );
-
-	2.1) markdown( TEXT, HASHREF );
-	2.2) markdown( CLASS, TEXT )
-	2.3) markdown( OBJ, TEXT )
-
-	3.1) markdown( CLASS, TEXT, HASHREF )
-	3.2) markdown( OBJ, TEXT, HASHREF )
-
-In 1), 2.2), and 3.1), we should make a new object and then do our
-thing.
-
-In 3.1), the previous version specifically said that we can't call
-this as a class method.
-
-In 3.2), we need to merge the options in the existing object with
-the new options. This was never a documented feature though.
-
-Part of the tickyness is that interface for Text::Markdown. We need
-to pass the HASHREF to _CleanUpRunData in the SUPER class
-
-=cut
-
-sub _looks_like_class {
-	local $_ = $_[0];
-	m/\A\w+(?:::\w+)+\z/;
-}
-
 sub markdown {
-	my( $self, $text, $options ) = do {
-		if ( @_ == 1 and ! ref $_[0] ) { # Case 1
-			( __PACKAGE__->new, $_[0], {} );
-		} elsif ( @_ == 2 and ! _looks_like_class($_[0]) and ref $_[1] eq ref {} ) { # Case 2.1
-			( __PACKAGE__->new( %{ $_[1] } ), $_[0], $_[1] );
-		} elsif ( @_ == 2 and _looks_like_class($_[0]) and ! ref $_[1] ) { # Case 2.2
-			( $_[0]->new, $_[1] );
-		} elsif ( @_ == 2 and blessed($_[0]) and ! ref $_[1] ) { # Case 2.3
-			( $_[0], $_[1], {} );
-		} elsif ( @_ == 3 and _looks_like_class($_[0]) and ! ref $_[1] and ref $_[2] eq ref {} ) { # Case 3.1
-			( $_[0]->new( %{ $_[2]} ), $_[1], $_[2] );
-		} elsif ( @_ == 3 and blessed($_[0]) and ! ref $_[1] and ref $_[2] eq ref {} ) { # Case 3.2
-			my %merged = ( %{ $_[0]->{params} }, %{ $_[2] } );
-			my $new = $_[0]->new( %merged );
-			( $new, $_[1], $_[2] );
-		} else {
-			carp "Unrecognized arguments for markdown()";
-			return;
-		}
-	};
+    my ( $self, $text, $options ) = @_;
 
-    $options = {} unless defined $options;
+    # Detect functional mode, and create an instance for this run..
+    unless (ref $self) {
+        if ( $self ne __PACKAGE__ ) {
+            my $ob = __PACKAGE__->new();
+                                # $self is text, $text is options
+            return $ob->markdown($self, $text);
+        }
+        else {
+            croak('Calling ' . $self . '->markdown (as a class method) is not supported.');
+        }
+    }
 
-	%$self = (%{ $self->{params} }, %$options, params => $self->{params});
-	$self->_CleanUpRunData($options);
+    $options ||= {};
+
+    %$self = (%{ $self->{params} }, %$options, params => $self->{params});
+
+    $self->_CleanUpRunData($options);
 
     return $self->_Markdown($text);
 }
 
-=item multimarkdown_to_html
-
-For the functional interface, you should use this instead of C<markdown>
-because it's a better name. At the moment it's the same as calling
-C<markdown>, but eventually this will diverge from the object-oriented
-form C<to_html>, which is also a better name.
-
-=cut
-
-sub multimarkdown_to_html {
-	markdown(@_);
-}
-
-=item to_html
-
-As a class or instance method, you should use this instead of C<markdown>
-because it's a better name. At the moment it's the same as calling
-C<markdown>, but eventually this will diverge from the functional
-form C<multimarkdown_to_html>, which is also a better name.
-
-=cut
-
-sub to_html {
-	markdown(@_);
-}
-
 sub _CleanUpRunData {
     my ($self, $options) = @_;
     # Clear the global hashes. If we don't clear these, you get conflicts
@@ -615,87 +365,6 @@ sub _DoHeaders {
     $text = $self->_DoTables($text);
 }
 
-sub _DoLists {
-    my ($self, $text) = @_;
-    $text = $self->_DoDefinitionLists($text)
-        unless $self->{disable_definition_lists};
-    $self->SUPER::_DoLists($text);
-}
-
-sub _DoDefinitionLists {
-    my ($self, $text) = @_;
-	# Uses the syntax proposed by Michel Fortin in PHP Markdown Extra
-
-	my $less_than_tab = $self->{tab_width} -1;
-
-	my $line_start = qr{
-		[ ]{0,$less_than_tab}
-	}mx;
-
-	my $term = qr{
-		$line_start
-		[^:\s][^\n]*\n
-	}sx;
-
-	my $definition = qr{
-		\n?[ ]{0,$less_than_tab}
-		\:[ \t]+(.*?)\n
-		((?=\n?\:)|\n|\Z)	# Lookahead for next definition, two returns,
-							# or the end of the document
-	}sx;
-
-	my $definition_block = qr{
-		((?:$term)+)				# $1 = one or more terms
-		((?:$definition)+)			# $2 = by one or more definitions
-	}sx;
-
-	my $definition_list = qr{
-		(?:$definition_block\n*)+		# One ore more definition blocks
-	}sx;
-
-	$text =~ s{
-		($definition_list)			# $1 = the whole list
-	}{
-		my $list = $1;
-		my $result = $1;
-
-		$list =~ s{
-			(?:$definition_block)\n*
-		}{
-			my $terms = $1;
-			my $defs = $2;
-
-			$terms =~ s{
-				[ ]{0,$less_than_tab}
-				(.*)
-				\s*
-			}{
-				my $term = $1;
-				my $result = "";
-				$term =~ s/^\s*(.*?)\s*$/$1/;
-				if ($term !~ /^\s*$/){
-					$result = "<dt>" . $self->_RunSpanGamut($1) . "</dt>\n";
-				}
-				$result;
-			}xmge;
-
-			$defs =~ s{
-				$definition
-			}{
-				my $def = $1 . "\n";
-				$def =~ s/^[ ]{0,$self->{tab_width}}//gm;
-				"<dd>\n" . $self->_RunBlockGamut($def) . "\n</dd>\n";
-			}xsge;
-
-			$terms . $defs . "\n";
-		}xsge;
-
-		"<dl>\n" . $list . "</dl>\n\n";
-	}xsge;
-
-	return $text
-}
-
 # Generating headers automatically generates X-refs in MultiMarkdown (always)
 # Also, by default, you get id attributes added to your headers, you can turn this
 # part of the MultiMarkdown behaviour off with the heading_ids flag.
@@ -1003,10 +672,10 @@ sub _DoFootnotes {
         if (defined $self->{_footnotes}{$id} ) {
             $footnote_counter++;
             if ($self->{_footnotes}{$id} =~ /^glossary:/i) {
-                $result = qq{<a href="$self->{self_url}#fn:$id" id="fnref:$id" class="footnote glossary">$footnote_counter</a>};
+                $result = qq{<a href="#fn:$id" id="fnref:$id" class="footnote glossary">$footnote_counter</a>};
             }
             else {
-                $result = qq{<a href="$self->{self_url}#fn:$id" id="fnref:$id" class="footnote">$footnote_counter</a>};
+                $result = qq{<a href="#fn:$id" id="fnref:$id" class="footnote">$footnote_counter</a>};
             }
             push (@{ $self->{_used_footnotes} }, $id);
         }
@@ -1056,10 +725,10 @@ sub _PrintFootnotes {
                 $glossary . q{:<p>};
             }egsx;
 
-            $result .= qq{<li id="fn:$id">$footnote<a href="$self->{self_url}#fnref:$id" class="reversefootnote">&#160;&#8617;</a>$footnote_closing_tag</li>\n\n};
+            $result .= qq{<li id="fn:$id">$footnote<a href="#fnref:$id" class="reversefootnote">&#160;&#8617;</a>$footnote_closing_tag</li>\n\n};
         }
         else {
-            $result .= qq{<li id="fn:$id">$footnote<a href="$self->{self_url}#fnref:$id" class="reversefootnote">&#160;&#8617;</a>$footnote_closing_tag</li>\n\n};
+            $result .= qq{<li id="fn:$id">$footnote<a href="#fnref:$id" class="reversefootnote">&#160;&#8617;</a>$footnote_closing_tag</li>\n\n};
         }
     }
 
@@ -1076,9 +745,10 @@ sub _PrintFootnotes {
 sub _Header2Label {
     my ($self, $header) = @_;
     my $label = lc $header;
-    $label =~ s/ +/-/g if $self->{heading_ids_spaces_to_dash};
-
-	return $self->_id_handler->($label);
+    $label =~ s/[^A-Za-z0-9:_.-]//g;        # Strip illegal characters
+    while ($label =~ s/^[^A-Za-z]//g)
+        {};     # Strip illegal leading characters
+    return $label;
 }
 
 sub _Id2Footnote {
@@ -1102,7 +772,7 @@ sub _xhtmlMetaData {
 
     foreach my $key (sort keys %{$self->{_metadata}} ) {
         if (lc($key) eq "title") {
-            $result.= "\t\t<title>" . encode_entities($self->{_metadata}{$key}) . "</title>\n";
+            $result.= "\t\t<title>$self->{_metadata}{$key}</title>\n";
         }
         elsif (lc($key) eq "css") {
             $result.= qq[\t\t<link type="text/css" rel="stylesheet" href="$self->{_metadata}{$key}"$self->{empty_element_suffix}\n];
@@ -1111,8 +781,7 @@ sub _xhtmlMetaData {
 			$result .= qq[\t\t$self->{_metadata}{$key}\n]
 		}
         else {
-            $result.= qq[\t\t<meta name="] . encode_entities($key) . qq[" ]
-                . qq[content="] . encode_entities($self->{_metadata}{$key}) . qq["$self->{empty_element_suffix}\n];
+            $result.= qq[\t\t<meta name="$key" content="$self->{_metadata}{$key}"$self->{empty_element_suffix}\n];
         }
     }
     $result.= "\t</head>\n";
@@ -1550,13 +1219,13 @@ sub _PrintMarkdownBibliography {
 
 1;
 
-=back
+__END__
 
 =head1 BUGS
 
-Open an issue in the GitHub repo:
+To file bug reports or feature requests please send email to:
 
-	https://github.com/briandfoy/text-multimarkdown/issues
+    bug-Text-Markdown@rt.cpan.org
 
 Please include with your report: (1) the example input; (2) the output
 you expected; (3) the output Markdown actually produced.
@@ -1567,26 +1236,24 @@ See the Changes file for detailed release notes for this version.
 
 =head1 AUTHOR
 
-=over 4
+    John Gruber
+    http://daringfireball.net/
 
-=item * John Gruber http://daringfireball.net/
+    PHP port and other contributions by Michel Fortin
+    http://michelf.com/
 
-=item * PHP port and other contributions by Michel Fortin http://michelf.com/
+    MultiMarkdown changes by Fletcher Penney
+    http://fletcher.freeshell.org/
 
-=item * MultiMarkdown changes by Fletcher Penney http://fletcher.freeshell.org/
+    CPAN Module Text::MultiMarkdown (based on Text::Markdown by Sebastian
+    Riedel) originally by Darren Kulp (http://kulp.ch/)
 
-=item * CPAN Module Text::MultiMarkdown (based on Text::Markdown by Sebastian Riedel) originally by Darren Kulp (http://kulp.ch/)
-
-=item * This module was maintained by: Tomas Doran http://www.bobtfish.net/
-
-=item * This module is currently maintained by brian d foy
-
-=back
+    This module is maintained by: Tomas Doran http://www.bobtfish.net/
 
 =head1 THIS DISTRIBUTION
 
 Please note that this distribution is a fork of Fletcher Penny's MultiMarkdown project,
-and it I<is not> in any way blessed by him.
+and it *is not* in any way blessed by him.
 
 Whilst this code aims to be compatible with the original MultiMarkdown (and incorporates
 and passes the MultiMarkdown test suite) whilst fixing a number of bugs in the original -
